import json
import sys
from pygisty.gisty import headless, post
from pygisty import options
from appdirs import *
from pygisty.options import fileoptions

def main():
    global authtoken
    appname = "pygisty"
    appauthor = "BlyatManGopnik"
    configdir = user_data_dir(appname, appauthor)
    if not os.path.exists(configdir):
        print("Creating " + configdir)
        os.makedirs(configdir)
    if len(sys.argv) > 3:
        print("Too many options. Exiting.")
        sys.exit(1)
    if len(sys.argv) == 2:
        options.options(sys.argv[1])
    clientid = "7da0ffca60ba4ae64eb3"
    print("pygisty v0.0.1")
    if os.path.exists(configdir + "/access_token.json") == False:
        authtoken = headless.headless(clientid, configdir)
    else:
        with open(configdir + "/access_token.json", "r") as configfile:
            jsondata = json.load(configfile)
            authtoken = jsondata["access_token"]
    if len(sys.argv) == 3:
        sentence = options.fileoptions(sys.argv[2], sys.argv[1])
    else:
        sentence = input("Put a sentence here!: ")
    if len(sys.argv) < 3:
        html = post.post(authtoken, sentence, "pygisty.txt")
    else:
        html = post.post(authtoken, sentence, sys.argv[2])
    print("We got the URL!: " + html)
if __name__ == '__main__':
    main()



import requests
import json
import time


def headless(clientid, configdir):
    global authtoken
    global headlessdone
    global devicecode
    headlessdone = False
    print(clientid)
    print("Starting headless GitHub authentication")
    pog = {"client_id": clientid, "scope": "gist"}
    header = {'User-Agent': "pygisty", "Accept": "application/json"}
    r = requests.Session()
    r.params.update(pog)
    r.headers.update(header)
    request = r.post('https://github.com/login/device/code')
    body = request.text
    dat = json.loads(body)
    try:
        error = dat["error"]
        print("Error: " + error)
        print(request.url)
    except KeyError:
        devicecode = dat["device_code"]
        print("I just received a code that you should enter at https://github.com/login/device\nCode: " + dat[
            "user_code"])
        while headlessdone == False:
            try:
                poggers = {"client_id": clientid, "device_code": devicecode,
                           "grant_type": "urn:ietf:params:oauth:grant-type:device_code"}
                s = requests.Session()
                s.params.update(poggers)
                s.headers.update(header)
                pogchamp = s.post("https://github.com/login/oauth/access_token")
                data = json.loads(pogchamp.text)
                authtoken = data["access_token"]
                print("We got the auth token!")
                accessjson = {
                    "access_token": authtoken
                }
                with open(configdir+"/access_token.json", "w") as configfile:
                    json.dump(accessjson, configfile)
                headlessdone = True
            except KeyError:
                time.sleep(5)
    return authtoken



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pygisty",
    version="0.0.3",
    author="BlyatManGopnik",
    author_email="emailforsurveys420@gmail.com",
    description="Bad GitHub Gist client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/BlyatManGopnik/pygisty",
    packages=setuptools.find_packages(),
    install_requires=[
        'requests',
        'appdirs'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
    entry_points={
        'console_scripts': [
            'pygisty=pygisty:main.main'
        ],
    },
)
